==> hboard-1.0-rc1.tar.gz: hboard/post_modify.php <==
<?php

/* EtchiBoard Version 1.0
     post_modify.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); // /ϴܺ
include ("lib/message.inc"); // ޽ function

PrintHeader();

//  ó: ^^+
$name = str_replace("", " ", $name);
$name = trim($name);
$title = str_replace("", " ", $title);
$title = trim($title);
$homepage = str_replace("", " ", $homepage);
$homepage = trim($homepage);
$email = str_replace("", " ", $email);
$email = trim($email);

/* ̸, ŸƲ, , йȣ  ϵ ʾ .. */
if($name == "" || $title == "" || $ne == "" || $article_no == "") {
 PrintMessage("<b>Ͱ  ۵ ʾҽϴ.</b><br> ʿ  ͸  äּ.", "error");
}

/* ̶.. */
else {

 if($homepage == "http://") {
  $homepage = ""; // http://  Ȩ 
 }

$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);
$result = mysql_query("select passwd,date,deleted from hboard_db_article where idx='${article_no}'", $dbconnect);

$article[passwd] = mysql_result($result, 0, "passwd"); // йȣ
$article[date] = mysql_result($result, 0, "date"); // ¥
$article[deleted] = mysql_result($result, 0, "deleted"); // 

/* йȣ  Ű Ȯ */
 if($passwd && crypt($passwd, HB) != $article[passwd]) {
  PrintMessage("йȣ ùٸ ʽϴ.", "error");
 }

 else if(!$passwd && $HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
  PrintMessage("<br>йȣ  ֽϴ.", "error");
 }

 else if($article[deleted] == "t") {
  PrintMessage("Խù ̹  Դϴ.", "error");
 }

 else {
 //  ̶.
  $article[date] = $article[date] ."*"; // ÿ ¥ * ϳ ٴ 0.x ǥ..Ѥ

  mysql_query("update hboard_db_article set name='${name}', email='${email}', home='${homepage}', date='${article[date]}', subject='${title}', ment='${ne}' where idx='${article_no}'") or die("ͺ̽  ߻!");

  // ޽ 
  PrintMessage("${article_no} Խù ۾ Ϸ߽ϴ.", "notice");
 }

 mysql_close($dbconnect);
}

PrintFooter();
?>

==> hboard-1.0.1.tar.gz: hboard/post_modify.php <==
<?php

/* EtchiBoard Version 1.0
     post_modify.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); // /ϴܺ
include ("lib/message.inc"); // ޽ function

PrintHeader();

//  ó: ^^+
$name = str_replace("", " ", $name);
$name = trim($name);
$title = str_replace("", " ", $title);
$title = trim($title);
$homepage = str_replace("", " ", $homepage);
$homepage = trim($homepage);
$email = str_replace("", " ", $email);
$email = trim($email);

/* ̸, ŸƲ, , йȣ  ϵ ʾ .. */
if($name == "" || $ne == "" || $article_no == "") {
 PrintMessage("<b>Ͱ  ۵ ʾҽϴ.</b><br> ʿ  ͸  äּ.", "error");
}

/* ̶.. */
else {

 if($homepage == "http://") {
  $homepage = ""; // http://  Ȩ 
 }

$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);
$result = mysql_query("select passwd,date,deleted from hboard_db_article where idx='${article_no}'", $dbconnect);

$article[passwd] = mysql_result($result, 0, "passwd"); // йȣ
$article[date] = mysql_result($result, 0, "date"); // ¥
$article[deleted] = mysql_result($result, 0, "deleted"); // 

/* йȣ  Ű Ȯ */
 if($passwd && crypt($passwd, HB) != $article[passwd]) {
  PrintMessage("йȣ ùٸ ʽϴ.", "error");
 }

 else if(!$passwd && $HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
  PrintMessage("<br>йȣ  ֽϴ.", "error");
 }

 else if($article[deleted] == "t") {
  PrintMessage("Խù ̹  Դϴ.", "error");
 }

 else {
 //  ̶.
  $article[date] = $article[date] ."*"; // ÿ ¥ * ϳ ٴ 0.x ǥ..Ѥ

  mysql_query("update hboard_db_article set name='${name}', email='${email}', home='${homepage}', date='${article[date]}', subject='${title}', ment='${ne}' where idx='${article_no}'") or die("ͺ̽  ߻!");

  // ޽ 
  PrintMessage("${article_no} Խù ۾ Ϸ߽ϴ.", "notice");
 }

 mysql_close($dbconnect);
}

PrintFooter();
?>
